<?xml version="1.0" ?><!DOCTYPE TS><TS language="pl_PL" version="2.0">
<context>
    <name>QuickLaunchButton</name>
    <message>
        <source>Move left</source>
        <translation>Przesuń w lewo</translation>
    </message>
    <message>
        <source>Move right</source>
        <translation>Przesuń w prawo</translation>
    </message>
    <message>
        <source>Remove from quicklaunch</source>
        <translation>Usuń z paska szybkiego uruchamiania</translation>
    </message>
</context>
<context>
    <name>RazorQuickLaunch</name>
    <message>
        <source>Drop Error</source>
        <translation>Problem dodawania</translation>
    </message>
    <message>
        <source>File/URL &apos;%1&apos; cannot be embedded into QuickLaunch for now</source>
        <translation>Plik/URL &apos;%1&apos; nie może zostać umiesczony na pasku szybkiego uruchamiania</translation>
    </message>
</context>
</TS>